@@ -54,9 +54,7 @@ describe 'tripleo::profile::base::nova' do
         is_expected.to contain_class('nova::config')
         is_expected.to contain_class('nova::logging')
         is_expected.to contain_class('nova::cache').with(
-          :enabled => true,
-          :backend => 'dogpile.cache.memcached',
-          :memcache_servers => ['127.0.0.1:11211']
+          :memcache_servers => ['controller-1:11211']
         )
         is_expected.to contain_class('nova::placement')
         is_expected.to contain_class('nova::keystone::service_user')
